# DO NOT EDIT -- This file automatically generated -- DO NOT EDIT
git_data = {
    "hash": "965eddb",
    "subject": "MBD: remove logging of last_sent in set_address",
    "ref_names": "HEAD -> devel-2022-10",
    "author_date": "Mon Oct 24 20:36:29 2022 -0700",
    "commit_date": "Mon Oct 24 20:36:29 2022 -0700",
}
source_data = {
    "git": git_data,
}
